@@ -149,17 +149,17 @@ class Rebuild(Library):
 
         return xml_string
 
-    def set_content_management_policy(self, input_file: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None):
+    def set_content_management_policy(self, input_file: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None):
         """ Sets the content management policy configuration. If input_file is None then default settings (sanitise) are applied.
 
         Args:
-            input_file (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): Default None (sanitise). The content management policy to apply.
+            input_file (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): Default None (sanitise). The content management policy to apply.
 
         Returns:
             status (int): The result of the Glasswall API call.
         """
         # Validate type
-        if not isinstance(input_file, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy)):
+        if not isinstance(input_file, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy)):
             raise TypeError(input_file)
 
         # self.library.GWFileConfigRevertToDefaults doesn't work, load default instead
@@ -186,13 +186,13 @@ class Rebuild(Library):
 
         return status
 
-    def protect_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def protect_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Protects a file using the current content management configuration, returning the file bytes. The protected file is written to output_file if it is provided.
 
         Args:
             input_file (Union[str, bytes, bytearray, io.BytesIO]): The input file path or bytes.
             output_file (Union[None, str], optional): The output file path where the protected file will be written.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -203,7 +203,7 @@ class Rebuild(Library):
             raise TypeError(input_file)
         if not isinstance(output_file, (type(None), str)):
             raise TypeError(output_file)
-        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy)):
+        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy)):
             raise TypeError(content_management_policy)
         if not isinstance(raise_unsupported, bool):
             raise TypeError(raise_unsupported)
@@ -320,9 +320,9 @@ class Rebuild(Library):
             else:
                 log.debug(f"\n\tstatus: {status}\n\tinput_file: {input_file_repr}\n\toutput_file: {output_file}")
                 if isinstance(input_file, str) and isinstance(output_file, str):
-                    # file to file, read the bytes of the file Glasswall has already written
+                    # file to file, read the bytes of the file that Rebuild has already written
                     if not os.path.isfile(output_file):
-                        log.warning(f"\n\tstatus: {status}\n\toutput_file: {output_file}")
+                        log.warning(f"Rebuild returned success code: {status} and no output file was found: {output_file}")
                         file_bytes = None
                     else:
                         with open(output_file, "rb") as f:
@@ -335,20 +335,20 @@ class Rebuild(Library):
                     )
                     if isinstance(output_file, str):
                         # memory to file
-                        # no Glasswall function exists for memory to file, write the memory to file ourselves
+                        # no Rebuild function exists for memory to file, write the memory to file ourselves
                         with open(output_file, "wb") as f:
                             f.write(file_bytes)
 
             return file_bytes
 
-    def protect_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def protect_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Recursively processes all files in a directory in protect mode using the given content management policy.
         The protected files are written to output_directory maintaining the same directory structure as input_directory.
 
         Args:
             input_directory (str): The input directory containing files to protect.
             output_directory (Union[None, str]): The output directory where the protected file will be written, or None to not write files.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): Default None (sanitise). The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): Default None (sanitise). The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -371,13 +371,13 @@ class Rebuild(Library):
 
         return protected_files_dict
 
-    def analyse_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def analyse_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Analyses a file, returning the analysis bytes. The analysis is written to output_file if it is provided.
 
         Args:
             input_file (Union[str, bytes, bytearray, io.BytesIO]): The input file path or bytes.
             output_file (Union[None, str], optional): The output file path where the analysis file will be written.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -388,7 +388,7 @@ class Rebuild(Library):
             raise TypeError(input_file)
         if not isinstance(output_file, (type(None), str)):
             raise TypeError(output_file)
-        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy)):
+        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy)):
             raise TypeError(content_management_policy)
         if not isinstance(raise_unsupported, bool):
             raise TypeError(raise_unsupported)
@@ -494,44 +494,43 @@ class Rebuild(Library):
                     ct.byref(ct_output_size)
                 )
 
+            if isinstance(input_file, str) and isinstance(output_file, str):
+                # file to file, read the bytes of the file that Rebuild has already written
+                if not os.path.isfile(output_file):
+                    log.warning(f"Rebuild returned success code: {status} and no output file was found: {output_file}")
+                    file_bytes = None
+                else:
+                    with open(output_file, "rb") as f:
+                        file_bytes = f.read()
+            else:
+                # file to memory, memory to memory
+                file_bytes = utils.buffer_to_bytes(
+                    ct_output_buffer,
+                    ct_output_size
+                )
+                if isinstance(output_file, str):
+                    # memory to file
+                    # no Rebuild function exists for memory to file, write the memory to file ourselves
+                    with open(output_file, "wb") as f:
+                        f.write(file_bytes)
+
             input_file_repr = f"{type(input_file)} length {len(input_file)}" if isinstance(input_file, (bytes, bytearray,)) else input_file.__sizeof__() if isinstance(input_file, io.BytesIO) else input_file
             if status not in successes.success_codes:
                 log.warning(f"\n\tstatus: {status}\n\tinput_file: {input_file_repr}\n\toutput_file: {output_file}")
                 if raise_unsupported:
                     raise errors.error_codes.get(status, errors.UnknownErrorCode)(status)
-                else:
-                    file_bytes = None
             else:
                 log.debug(f"\n\tstatus: {status}\n\tinput_file: {input_file_repr}\n\toutput_file: {output_file}")
-                if isinstance(input_file, str) and isinstance(output_file, str):
-                    # file to file, read the bytes of the file Glasswall has already written
-                    if not os.path.isfile(output_file):
-                        log.warning(f"\n\tstatus: {status}\n\toutput_file: {output_file}")
-                        file_bytes = None
-                    else:
-                        with open(output_file, "rb") as f:
-                            file_bytes = f.read()
-                else:
-                    # file to memory, memory to memory
-                    file_bytes = utils.buffer_to_bytes(
-                        ct_output_buffer,
-                        ct_output_size
-                    )
-                    if isinstance(output_file, str):
-                        # memory to file
-                        # no Glasswall function exists for memory to file, write the memory to file ourselves
-                        with open(output_file, "wb") as f:
-                            f.write(file_bytes)
 
             return file_bytes
 
-    def analyse_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def analyse_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Analyses all files in a directory and its subdirectories. The analysis files are written to output_directory maintaining the same directory structure as input_directory.
 
         Args:
             input_directory (str): The input directory containing files to analyse.
             output_directory (Union[None, str]): The output directory where the analysis files will be written, or None to not write files.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): Default None (sanitise). The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): Default None (sanitise). The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -554,13 +553,13 @@ class Rebuild(Library):
 
         return analysis_files_dict
 
-    def export_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def export_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Export a file, returning the .zip file bytes. The .zip file is written to output_file.
 
         Args:
             input_file (Union[str, bytes, bytearray, io.BytesIO]): The input file path or bytes.
             output_file (Union[None, str], optional): The output file path where the .zip file will be written.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -571,7 +570,7 @@ class Rebuild(Library):
             raise TypeError(input_file)
         if not isinstance(output_file, (type(None), str)):
             raise TypeError(output_file)
-        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy)):
+        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy)):
             raise TypeError(content_management_policy)
         if not isinstance(raise_unsupported, bool):
             raise TypeError(raise_unsupported)
@@ -678,9 +677,9 @@ class Rebuild(Library):
             else:
                 log.debug(f"\n\tstatus: {status}\n\tinput_file: {input_file_repr}\n\toutput_file: {output_file}")
                 if isinstance(input_file, str) and isinstance(output_file, str):
-                    # file to file, read the bytes of the file Glasswall has already written
+                    # file to file, read the bytes of the file that Rebuild has already written
                     if not os.path.isfile(output_file):
-                        log.warning(f"\n\tstatus: {status}\n\toutput_file: {output_file}")
+                        log.warning(f"Rebuild returned success code: {status} and no output file was found: {output_file}")
                         file_bytes = None
                     else:
                         with open(output_file, "rb") as f:
@@ -693,19 +692,19 @@ class Rebuild(Library):
                     )
                     if isinstance(output_file, str):
                         # memory to file
-                        # no Glasswall function exists for memory to file, write the memory to file ourselves
+                        # no Rebuild function exists for memory to file, write the memory to file ourselves
                         with open(output_file, "wb") as f:
                             f.write(file_bytes)
 
             return file_bytes
 
-    def export_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def export_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Exports all files in a directory and its subdirectories. The export files are written to output_directory maintaining the same directory structure as input_directory.
 
         Args:
             input_directory (str): The input directory containing files to export.
             output_directory (Union[None, str]): The output directory where the export files will be written, or None to not write files.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): Default None (sanitise). The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): Default None (sanitise). The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -728,13 +727,13 @@ class Rebuild(Library):
 
         return export_files_dict
 
-    def import_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def import_file(self, input_file: Union[str, bytes, bytearray, io.BytesIO], output_file: Union[None, str] = None, content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Import a .zip file, constructs a file from the .zip file and returns the file bytes. The file is written to output_file if it is provided.
 
         Args:
             input_file (Union[str, bytes, bytearray, io.BytesIO]): The .zip input file path or bytes.
             output_file (Union[None, str], optional): The output file path where the constructed file will be written.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): The content management policy to apply to the session.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): The content management policy to apply to the session.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
@@ -745,7 +744,7 @@ class Rebuild(Library):
             raise TypeError(input_file)
         if not isinstance(output_file, (type(None), str)):
             raise TypeError(output_file)
-        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy)):
+        if not isinstance(content_management_policy, (type(None), str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy)):
             raise TypeError(content_management_policy)
         if not isinstance(raise_unsupported, bool):
             raise TypeError(raise_unsupported)
@@ -852,9 +851,9 @@ class Rebuild(Library):
             else:
                 log.debug(f"\n\tstatus: {status}\n\tinput_file: {input_file_repr}\n\toutput_file: {output_file}")
                 if isinstance(input_file, str) and isinstance(output_file, str):
-                    # file to file, read the bytes of the file Glasswall has already written
+                    # file to file, read the bytes of the file that Rebuild has already written
                     if not os.path.isfile(output_file):
-                        log.warning(f"\n\tstatus: {status}\n\toutput_file: {output_file}")
+                        log.warning(f"Rebuild returned success code: {status} and no output file was found: {output_file}")
                         file_bytes = None
                     else:
                         with open(output_file, "rb") as f:
@@ -867,20 +866,20 @@ class Rebuild(Library):
                     )
                     if isinstance(output_file, str):
                         # memory to file
-                        # no Glasswall function exists for memory to file, write the memory to file ourselves
+                        # no Rebuild function exists for memory to file, write the memory to file ourselves
                         with open(output_file, "wb") as f:
                             f.write(file_bytes)
 
             return file_bytes
 
-    def import_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.Policy"] = None, raise_unsupported: bool = True):
+    def import_directory(self, input_directory: str, output_directory: Union[None, str], content_management_policy: Union[None, str, bytes, bytearray, io.BytesIO, "glasswall.content_management.policies.policy.Policy"] = None, raise_unsupported: bool = True):
         """ Imports all files in a directory and its subdirectories. Files are expected as .zip but this is not forced.
         The constructed files are written to output_directory maintaining the same directory structure as input_directory.
 
         Args:
             input_directory (str): The input directory containing files to import.
             output_directory (Union[None, str]): The output directory where the constructed files will be written, or None to not write files.
-            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.Policy], optional): Default None (sanitise). The content management policy to apply.
+            content_management_policy (Union[None, str, bytes, bytearray, io.BytesIO, glasswall.content_management.policies.policy.Policy], optional): Default None (sanitise). The content management policy to apply.
             raise_unsupported (bool, optional): Default True. Raise exceptions when Glasswall encounters an error. Fail silently if False.
 
         Returns:
